==> wire-runtime-3.1.0-javadoc.jar: wire-runtime/com.squareup.wire/-android-message/index.md <==
[wire-runtime](../../index.md) / [com.squareup.wire](../index.md) / [AndroidMessage](./index.md)

# AndroidMessage

`abstract class AndroidMessage<M : `[`Message`](../-message/index.md)`<`[`M`](index.md#M)`, `[`B`](index.md#B)`>, B : `[`Builder`](../-message/-builder/index.md)`<`[`M`](index.md#M)`, `[`B`](index.md#B)`>> : `[`Message`](../-message/index.md)`<`[`M`](index.md#M)`, `[`B`](index.md#B)`>`

**Platform and version requirements:** JVM

An Android-specific [Message](../-message/index.md) which adds support for [Parcelable](#).

### Constructors

| Name | Summary |
|---|---|
| [&lt;init&gt;](-init-.md) | `AndroidMessage(adapter: `[`ProtoAdapter`](../-proto-adapter/index.md)`<`[`M`](index.md#M)`>, unknownFields: <ERROR CLASS>)`<br>An Android-specific [Message](../-message/index.md) which adds support for [Parcelable](#). |

### Inherited Properties

| Name | Summary |
|---|---|
| [adapter](../-message/adapter.md)<br>(JVM, js, native) | `val adapter: `[`ProtoAdapter`](../-proto-adapter/index.md)`<`[`M`](../-message/index.md#M)`>`<br>The [ProtoAdapter](../-proto-adapter/index.md) for encoding and decoding messages of this type. |
| [hashCode](../-message/hash-code.md)<br>(JVM, js, native) | `var hashCode: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)<br>If non-zero, the hash code of this message. Accessed by generated code. |
| [unknownFields](../-message/unknown-fields.md)<br>(JVM, js, native) | `val unknownFields: <ERROR CLASS>`<br>Returns a byte string containing the proto encoding of this message's unknown fields. Returns an empty byte string if this message has no unknown fields. |

### Functions

| Name | Summary |
|---|---|
| [describeContents](describe-contents.md) | `open fun describeContents(): `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |
| [writeToParcel](write-to-parcel.md) | `open fun writeToParcel(dest: <ERROR CLASS>, flags: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |

### Inherited Functions

| Name | Summary |
|---|---|
| [encode](../-message/encode.md)<br>(JVM) | `fun encode(): `[`ByteArray`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-byte-array/index.html)<br>Encode this message as a `byte[]`.`fun encode(stream: `[`OutputStream`](http://docs.oracle.com/javase/8/docs/api/java/io/OutputStream.html)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html)<br>Encode this message and write it to `stream`. |
| [newBuilder](../-message/new-builder.md)<br>(JVM, js, native) | `abstract fun newBuilder(): `[`B`](../-message/index.md#B)<br>Returns a new builder initialized with the data in this message. |
| [toString](../-message/to-string.md)<br>(JVM, js, native) | `open fun toString(): `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [withoutUnknownFields](../-message/without-unknown-fields.md)<br>(JVM) | `fun withoutUnknownFields(): `[`M`](../-message/index.md#M)<br>Returns this message with any unknown fields removed. |
| [writeReplace](../-message/write-replace.md)<br>(JVM) | `fun writeReplace(): `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html) |

### Companion Object Functions

| Name | Summary |
|---|---|
| [newCreator](new-creator.md) | `fun <E> newCreator(adapter: `[`ProtoAdapter`](../-proto-adapter/index.md)`<`[`E`](new-creator.md#E)`>): <ERROR CLASS><`[`E`](new-creator.md#E)`>`<br>Creates a new [Parcelable.Creator](#) using `adapter` for serialization. |

==> wire-runtime-3.7.1-javadoc.jar: wire-runtime/com.squareup.wire/-android-message/index.md <==
[wire-runtime](../../index.md) / [com.squareup.wire](../index.md) / [AndroidMessage](./index.md)

# AndroidMessage

`abstract class AndroidMessage<M : `[`Message`](../-message/index.md)`<`[`M`](index.md#M)`, `[`B`](index.md#B)`>, B : `[`Builder`](../-message/-builder/index.md)`<`[`M`](index.md#M)`, `[`B`](index.md#B)`>> : `[`Message`](../-message/index.md)`<`[`M`](index.md#M)`, `[`B`](index.md#B)`>`

**Platform and version requirements:** JVM

An Android-specific [Message](../-message/index.md) which adds support for [Parcelable](#).

### Constructors

| Name | Summary |
|---|---|
| [&lt;init&gt;](-init-.md) | `AndroidMessage(adapter: `[`ProtoAdapter`](../-proto-adapter/index.md)`<`[`M`](index.md#M)`>, unknownFields: <ERROR CLASS>)`<br>An Android-specific [Message](../-message/index.md) which adds support for [Parcelable](#). |

### Inherited Properties

| Name | Summary |
|---|---|
| [adapter](../-message/adapter.md)<br>(JVM, js, native) | `val adapter: `[`ProtoAdapter`](../-proto-adapter/index.md)`<`[`M`](../-message/index.md#M)`>`<br>The [ProtoAdapter](../-proto-adapter/index.md) for encoding and decoding messages of this type. |
| [hashCode](../-message/hash-code.md)<br>(JVM, js, native) | `var hashCode: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)<br>If non-zero, the hash code of this message. Accessed by generated code. |
| [unknownFields](../-message/unknown-fields.md)<br>(JVM, js, native) | `val unknownFields: <ERROR CLASS>`<br>Returns a byte string containing the proto encoding of this message's unknown fields. Returns an empty byte string if this message has no unknown fields. |

### Functions

| Name | Summary |
|---|---|
| [describeContents](describe-contents.md) | `open fun describeContents(): `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |
| [writeToParcel](write-to-parcel.md) | `open fun writeToParcel(dest: <ERROR CLASS>, flags: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |

### Inherited Functions

| Name | Summary |
|---|---|
| [encode](../-message/encode.md)<br>(JVM) | `fun encode(): `[`ByteArray`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-byte-array/index.html)<br>Encode this message as a `byte[]`.`fun encode(stream: `[`OutputStream`](http://docs.oracle.com/javase/8/docs/api/java/io/OutputStream.html)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html)<br>Encode this message and write it to `stream`. |
| [encodeByteString](../-message/encode-byte-string.md)<br>(JVM, js, native) | `fun encodeByteString(): <ERROR CLASS>`<br>Encode this message as a `ByteString`. |
| [newBuilder](../-message/new-builder.md)<br>(JVM, js, native) | `abstract fun newBuilder(): `[`B`](../-message/index.md#B)<br>Returns a new builder initialized with the data in this message. |
| [toString](../-message/to-string.md)<br>(JVM, js, native) | `open fun toString(): `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [withoutUnknownFields](../-message/without-unknown-fields.md)<br>(JVM) | `fun withoutUnknownFields(): `[`M`](../-message/index.md#M)<br>Returns this message with any unknown fields removed. |
| [writeReplace](../-message/write-replace.md)<br>(JVM) | `fun writeReplace(): `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html) |

### Companion Object Functions

| Name | Summary |
|---|---|
| [newCreator](new-creator.md) | `fun <E> newCreator(adapter: `[`ProtoAdapter`](../-proto-adapter/index.md)`<`[`E`](new-creator.md#E)`>): <ERROR CLASS><`[`E`](new-creator.md#E)`>`<br>Creates a new [Parcelable.Creator](#) using `adapter` for serialization. |
